About Us
========

HoloViews is supported and maintained by `Anaconda <https://www.anaconda.com>`_.

The primary developers are Jean-Luc Stevens, Philipp Rudiger, and
James A. Bednar, with bug reports and patches from numerous members of
the Github community.

Prior Funding
-------------

.. image:: http://www.anc.ed.ac.uk/anc.png
   :height: 60px
   :alt: ANC website
   :align: left
   :target: http://www.anc.ed.ac.uk

The original development of HoloViews was supported in part by Grants EP/F500385/1 and BB/F529254/1 
to the `University of Edinburgh 
Doctoral Training Centre in Neuroinformatics and Computational Neuroscience <http://www.anc.ed.ac.uk/dtc>`_ 
from the UK Engineering and Physical Sciences Research Council, 
Biotechnology and Biological Sciences Research Council, and
Medical Research Council.

